@@ -1,3 +1,5 @@
+#!/usr/bin/env python3
+
 import os
 import glob
 import argparse
@@ -18,26 +20,27 @@ dbCAN_parser_usage = '''
 module load hmmer/3.2.1
 
 # annotate protein sequences
-BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN -i recipient.faa 
-BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN -i recipient.faa -depth recipient.depth
-BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN -i faa_files -x faa
-BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN -i faa_files -x faa -depth depth_files
+BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN_V9 -i recipient.faa 
+BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN_V9 -i recipient.faa -depth recipient.depth
+BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN_V9 -i faa_files -x faa
+BioSAK dbCAN -m P -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN_V9 -i faa_files -x faa -depth depth_files
 
 # annotate DNA sequences
-BioSAK dbCAN -m N -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN -i recipient.ffn
-BioSAK dbCAN -m N -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN -i ffn_files -x ffn
+BioSAK dbCAN -m N -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN_V9 -i recipient.ffn
+BioSAK dbCAN -m N -t 6 -db_dir /srv/scratch/z5039045/DB/dbCAN_V9 -i ffn_files -x ffn
 
 # Depth file format (one gene per line, tab separated)
 gene_1	30
 gene_2	10.58
 gene_3	10.58
 
-# DB files (cd to your db_dir and run the following commands):
-cd $db_dir
-wget http://bcb.unl.edu/dbCAN2/download/Databases/dbCAN-old@UGA/hmmscan-parser.sh
-wget http://bcb.unl.edu/dbCAN2/download/Databases/dbCAN-old@UGA/dbCAN-fam-HMMs.txt
-wget http://bcb.unl.edu/dbCAN2/download/Databases/CAZyDB.07312019.fam-activities.txt
-mv CAZyDB.07312019.fam-activities.txt CAZyDB.fam-activities.txt
+# DB files (versions V9):
+cd dbCAN_V9
+wget http://bcb.unl.edu/dbCAN2/download/Databases/V9/hmmscan-parser.sh
+wget http://bcb.unl.edu/dbCAN2/download/Databases/V9/CAZyDB.07302020.fam-activities.txt
+wget http://bcb.unl.edu/dbCAN2/download/Databases/V9/dbCAN-HMMdb-V9.txt
+mv CAZyDB.07302020.fam-activities.txt CAZyDB.fam-activities.txt
+mv dbCAN-HMMdb-V9.txt dbCAN-fam-HMMs.txt
 hmmpress dbCAN-fam-HMMs.txt
 
 # How it works:
@@ -150,13 +153,14 @@ def dbCAN_worker(argument_list):
         query_id = hmm_hit_split[2]
         matched_hmm = hmm_hit_split[0]
         matched_hmm_id = matched_hmm.split('.hmm')[0]
-        if '_' in matched_hmm_id:
-            matched_hmm_id = matched_hmm_id.split('_')[0]
 
         # get activities
         matched_hmm_activities = 'NA'
-        if matched_hmm_id in fam_to_activities_dict:
-            matched_hmm_activities = fam_to_activities_dict[matched_hmm_id]
+        matched_hmm_id_no_underscore = matched_hmm_id
+        if '_' in matched_hmm_id_no_underscore:
+            matched_hmm_id_no_underscore = matched_hmm_id_no_underscore.split('_')[0]
+        if matched_hmm_id_no_underscore in fam_to_activities_dict:
+            matched_hmm_activities = fam_to_activities_dict[matched_hmm_id_no_underscore]
 
         # get hmm_to_num_dict
         if matched_hmm_id not in hmm_to_gene_member_dict:
@@ -176,16 +180,15 @@ def dbCAN_worker(argument_list):
     pwd_annotation_results_stats_GeneNumber_handle.write('Family\tGeneNumber\tActivities\n')
     total_GeneNumber_identified = 0
     for each_hmm in hmm_to_gene_member_dict:
-
         each_hmm_id = each_hmm.split('.hmm')[0]
-        if '_' in each_hmm_id:
-            each_hmm_id = each_hmm_id.split('_')[0]
-
         each_hmm_GeneNumber = len(hmm_to_gene_member_dict[each_hmm_id])
 
         each_hmm_activities = 'NA'
-        if each_hmm_id in fam_to_activities_dict:
-            each_hmm_activities = fam_to_activities_dict[each_hmm_id]
+        matched_hmm_id_no_underscore = each_hmm_id
+        if '_' in matched_hmm_id_no_underscore:
+            matched_hmm_id_no_underscore = matched_hmm_id_no_underscore.split('_')[0]
+        if matched_hmm_id_no_underscore in fam_to_activities_dict:
+            each_hmm_activities = fam_to_activities_dict[matched_hmm_id_no_underscore]
 
         pwd_annotation_results_stats_GeneNumber_handle.write('%s\t%s\t%s\n' % (each_hmm_id, each_hmm_GeneNumber, each_hmm_activities))
         total_GeneNumber_identified += each_hmm_GeneNumber
@@ -202,11 +205,7 @@ def dbCAN_worker(argument_list):
         pwd_annotation_results_stats_TotalDepth_handle.write('Family\tTotalDepth\tActivities\n')
         total_depth_identified = 0
         for each_hmm in hmm_to_gene_member_dict:
-
             each_hmm_id = each_hmm.split('.hmm')[0]
-            if '_' in each_hmm_id:
-                each_hmm_id = each_hmm_id.split('_')[0]
-
             each_hmm_TotalDepth = 0
             for each_gene in hmm_to_gene_member_dict[each_hmm_id]:
                 each_gene_depth = gene_depth_dict[each_gene]
@@ -214,8 +213,11 @@ def dbCAN_worker(argument_list):
             each_hmm_TotalDepth = float("{0:.2f}".format(each_hmm_TotalDepth))
 
             each_hmm_activities = 'NA'
-            if each_hmm_id in fam_to_activities_dict:
-                each_hmm_activities = fam_to_activities_dict[each_hmm_id]
+            matched_hmm_id_no_underscore = each_hmm_id
+            if '_' in matched_hmm_id_no_underscore:
+                matched_hmm_id_no_underscore = matched_hmm_id_no_underscore.split('_')[0]
+            if matched_hmm_id_no_underscore in fam_to_activities_dict:
+                each_hmm_activities = fam_to_activities_dict[matched_hmm_id_no_underscore]
 
             pwd_annotation_results_stats_TotalDepth_handle.write('%s\t%s\t%s\n' % (each_hmm_id, each_hmm_TotalDepth, each_hmm_activities))
             total_depth_identified += each_hmm_TotalDepth
