@@ -1,51 +1,52 @@
 import os
 import glob
 import argparse
+from subprocess import Popen
 from datetime import datetime
 import multiprocessing as mp
 
 
 get_genome_NCBI_parser_usage = '''
-================================== get_genome_NCBI example commands ==================================
+===================================== get_genome_NCBI example commands =====================================
 
 # Usage:
-1. Go to https://www.ncbi.nlm.nih.gov/genome/browse#!/prokaryotes/refseq_category:reference
-2. Search the taxonomy of genomes you want to download (e.g. prokaryotes, proteobacteria)
-3. Click "Download" on the right side
-4. provide the downloaded csv file to BioSAK with '-csv'
+Before you start, you need to download https://ftp.ncbi.nlm.nih.gov/genomes/GENOME_REPORTS/prokaryotes.txt
+and provide it to get_genome_NCBI with '-db'.
 
-# Example commands
-BioSAK get_genome_NCBI -csv prokaryotes.csv -out gnm_dir -fna -name -t 8
-BioSAK get_genome_NCBI -csv prokaryotes.csv -out gnm_dir -fna -faa -name -t 8
-BioSAK get_genome_NCBI -csv prokaryotes.csv -id ids.txt -out gnm_dir -fna -gbff -name -t 8 
+# Download genomes in the gnms_to_download.txt
+BioSAK get_genome_NCBI -db prokaryotes.txt -out gnm_dir -id gnms_to_download.txt -t 8 -fna
+BioSAK get_genome_NCBI -db prokaryotes.txt -out gnm_dir -id gnms_to_download.txt -t 8 -fna -faa -name
 
-# id file format (the 6th col of the downloaded csv file, one id per line)
+# Format of gnms_to_download.txt (genome ID can be found in the "Assembly Accession" column of the prokaryotes.txt)
 GCA_009840555.1
 GCA_009840575.1
 
-=====================================================================================================
+# You can get the id of genomes from a specific taxon using this link, IDs are in the "Assembly" column.
+https://www.ncbi.nlm.nih.gov/genome/browse#!/prokaryotes/refseq_category:reference
+
+============================================================================================================
 '''
 
 
 def genome_download_worker(argument_list):
 
     genome_record_split =      argument_list[0]
-    downloaded_genome_folder = argument_list[1]
-    get_fna =                  argument_list[2]
-    get_faa =                  argument_list[3]
-    get_gbff =                 argument_list[4]
-    with_name =                argument_list[5]
+    col_index =                argument_list[1]
+    downloaded_genome_folder = argument_list[2]
+    get_fna =                  argument_list[3]
+    get_faa =                  argument_list[4]
+    get_gbff =                 argument_list[5]
+    with_name =                argument_list[6]
 
-    genome_name = genome_record_split[0][1:-1]
+    genome_name = genome_record_split[0]
     genome_name_no_space = '_'.join(genome_name.split(' '))
     if ('(' in genome_name_no_space) and (')' in genome_name_no_space):
         genome_name_no_space_no_parenthesis_tmp = genome_name_no_space.replace('(', '_')
         genome_name_no_space = genome_name_no_space_no_parenthesis_tmp.replace(')', '')
 
-
-    GenBank_FTP = genome_record_split[-2][1:-1]
+    GenBank_FTP = genome_record_split[col_index['FTP Path']]
+    assembly_id = genome_record_split[col_index['Assembly Accession']]
     GenBank_FTP_id = GenBank_FTP.strip().split('/')[-1]
-    assembly_id = genome_record_split[5]
 
     # prepare cmds
     fna_file =                  '%s_genomic.fna.gz'                     % (GenBank_FTP_id)
@@ -60,6 +61,9 @@ def genome_download_worker(argument_list):
     wget_fna_cmd =              'wget %s -P %s -q'                      % (ftp_fna_file, downloaded_genome_folder)
     wget_faa_cmd =              'wget %s -P %s -q'                      % (ftp_faa_file, downloaded_genome_folder)
     wget_gbff_cmd =             'wget %s -P %s -q'                      % (ftp_gbff_file, downloaded_genome_folder)
+    curl_fna_cmd  =             'curl %s -o %s/%s -s'                   % (ftp_fna_file,  downloaded_genome_folder, fna_file)
+    curl_faa_cmd  =             'curl %s -o %s/%s -s'                   % (ftp_faa_file,  downloaded_genome_folder, faa_file)
+    curl_gbff_cmd =             'curl %s -o %s/%s -s'                   % (ftp_gbff_file, downloaded_genome_folder, gbff_file)
     gunzip_fna_cmd =            'gunzip %s'                             % (pwd_fna_file)
     gunzip_faa_cmd =            'gunzip %s'                             % (pwd_faa_file)
     gunzip_gbff_cmd =           'gunzip %s'                             % (pwd_gbff_file)
@@ -73,6 +77,10 @@ def genome_download_worker(argument_list):
     # download, decompress and rename
     if get_fna is True:
         os.system(wget_fna_cmd)
+        #wget_fna_cmd.replace('ftp', 'https')
+        #print(curl_fna_cmd)
+        #os.system(curl_fna_cmd)
+        #Popen(curl_fna_cmd, shell=True).wait()
         if os.path.isfile(pwd_fna_file) is True:
             os.system(gunzip_fna_cmd)
             if with_name is False:
@@ -80,7 +88,7 @@ def genome_download_worker(argument_list):
             else:
                 os.system(rename_fna_cmd_with_name)
         else:
-            print('fna file not found in: %s/' % (GenBank_FTP))
+            print('fna file not found in: %s/' % GenBank_FTP)
 
     if get_faa is True:
         os.system(wget_faa_cmd)
@@ -91,7 +99,7 @@ def genome_download_worker(argument_list):
             else:
                 os.system(rename_faa_cmd_with_name)
         else:
-            print('faa file not found in: %s/' % (GenBank_FTP))
+            print('faa file not found in: %s/' % GenBank_FTP)
 
     if get_gbff is True:
         os.system(wget_gbff_cmd)
@@ -102,12 +110,12 @@ def genome_download_worker(argument_list):
             else:
                 os.system(rename_gbff_cmd_with_name)
         else:
-            print('gbff file not found in: %s/' % (GenBank_FTP))
+            print('gbff file not found in: %s/' % GenBank_FTP)
 
 
 def download_GenBank_genome(args):
 
-    csv_file =          args['csv']
+    csv_file =          args['db']
     output_folder =     args['out']
     assembly_id_file =  args['id']
     get_fna =           args['fna']
@@ -115,6 +123,7 @@ def download_GenBank_genome(args):
     get_gbff =          args['gbff']
     with_name =         args['name']
     num_threads =       args['t']
+    force_overwrite =   args['force']
 
     time_format = '[%Y-%m-%d %H:%M:%S] '
 
@@ -122,6 +131,13 @@ def download_GenBank_genome(args):
         print(datetime.now().strftime(time_format) + 'Please specify at least one file type to download, program exited')
         exit()
 
+    if os.path.isdir(output_folder) is True:
+        if force_overwrite is True:
+            os.system('rm -r %s' % output_folder)
+        else:
+            print(datetime.now().strftime(time_format) + 'Specified genome directory detected, program exited!')
+            exit()
+
     os.mkdir(output_folder)
 
     # report
@@ -141,23 +157,26 @@ def download_GenBank_genome(args):
     genomes_in_csv = set()
     genomes_in_csv_no_version = set()
     list_for_multiple_arguments_download_worker = []
+    col_index = {}
     for genome_record in open(csv_file):
-        if not genome_record.startswith('#Organism Name'):
-            genome_record_split = genome_record.strip().split(',')
-            assembly_id = genome_record_split[5][1:-1]
-            assembly_id_no_version = genome_record_split[5][1:-1].split('.')[0]
+        genome_record_split = genome_record.strip().split('\t')
+        if genome_record.startswith('#Organism/Name'):
+            col_index = {key: i for i, key in enumerate(genome_record_split)}
+        else:
+            assembly_id = genome_record_split[col_index['Assembly Accession']]
+            assembly_id_no_version = assembly_id.split('.')[0]
             if assembly_id_file is None:
-                list_for_multiple_arguments_download_worker.append([genome_record_split, output_folder, get_fna, get_faa, get_gbff, with_name])
+                list_for_multiple_arguments_download_worker.append([genome_record_split, col_index, output_folder, get_fna, get_faa, get_gbff, with_name])
                 genomes_in_csv.add(assembly_id)
                 genomes_in_csv_no_version.add(assembly_id.split('.')[0])
             else:
                 if assembly_id in assembly_id_set:
-                    list_for_multiple_arguments_download_worker.append([genome_record_split, output_folder, get_fna, get_faa, get_gbff, with_name])
+                    list_for_multiple_arguments_download_worker.append([genome_record_split, col_index, output_folder, get_fna, get_faa, get_gbff, with_name])
                 elif assembly_id_no_version in assembly_id_set_no_version:
-                    list_for_multiple_arguments_download_worker.append([genome_record_split, output_folder, get_fna, get_faa, get_gbff, with_name])
+                    list_for_multiple_arguments_download_worker.append([genome_record_split, col_index, output_folder, get_fna, get_faa, get_gbff, with_name])
                     different_version_found_dict[assembly_id_no_version] = assembly_id
 
-    # run COG annotaion files with multiprocessing
+    # run with multiprocessing
     pool = mp.Pool(processes=num_threads)
     pool.map(genome_download_worker, list_for_multiple_arguments_download_worker)
     pool.close()
@@ -205,14 +224,14 @@ def download_GenBank_genome(args):
 if __name__ == '__main__':
 
     parser = argparse.ArgumentParser()
-    parser.add_argument('-csv',         required=True,                       help='csv file downloaded from NCBI genome_browse')
+    parser.add_argument('-db',          required=True,                       help='local path to prokaryotes.txt')
     parser.add_argument('-out',         required=True,                       help='output folder')
-    parser.add_argument('-id',          required=False, default=None,        help='assembly id (6th col in the csv file), one id per line')
+    parser.add_argument('-id',          required=False, default=None,        help='IDs of genomes to download')
     parser.add_argument('-fna',         required=False, action="store_true", help='download fna file')
     parser.add_argument('-faa',         required=False, action="store_true", help='download faa file')
     parser.add_argument('-gbff',        required=False, action="store_true", help='download gbff file')
     parser.add_argument('-name',        required=False, action="store_true", help='include genome name in the downloaded files')
+    parser.add_argument('-force',       required=False, action="store_true", help='force overwrite existing genome directory')
     parser.add_argument('-t',           required=False, default=1, type=int, help='number of threads')
     args = vars(parser.parse_args())
     download_GenBank_genome(args)
-
